
/* Generated data (by glib-mkenums) */

#include <glib-object.h>

/* enumerations from "/home/paolo/workspace/gthumb/extensions/pixbuf_savers/preferences.h" */
#include "/home/paolo/workspace/gthumb/extensions/pixbuf_savers/preferences.h"
GType
gth_tiff_compression_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TIFF_COMPRESSION_NONE, "GTH_TIFF_COMPRESSION_NONE", "none" },
      { GTH_TIFF_COMPRESSION_DEFLATE, "GTH_TIFF_COMPRESSION_DEFLATE", "deflate" },
      { GTH_TIFF_COMPRESSION_JPEG, "GTH_TIFF_COMPRESSION_JPEG", "jpeg" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTiffCompression", values);
  }
  return etype;
}

/* Generated data ends here */

